@@ -1,5 +1,7 @@
+#pragma once
+
 #include "includes.hpp"
-#include "debug/Log.hpp"
+#include "debug/log/Logger.hpp"
 #include "helpers/Color.hpp"
 #include "macros.hpp"
 #include "desktop/DesktopTypes.hpp"
