@@ -1,11 +1,11 @@
 #pragma once
-#define GIT_COMMIT_HASH    "39f3feddbee4a66be9608ed1eb7e73878d596b50"
-#define GIT_BRANCH         "v0.53.2"
-#define GIT_COMMIT_MESSAGE "[gha] Nix: update inputs"
-#define GIT_COMMIT_DATE    "Fri Jan 23 13:15:35 2026"
+#define GIT_COMMIT_HASH    "dd220efe7b1e292415bd0ea7161f63df9c95bfd3"
+#define GIT_BRANCH         "v0.53.3"
+#define GIT_COMMIT_MESSAGE "version: bump to 0.53.3"
+#define GIT_COMMIT_DATE    "Sat Jan 24 20:02:06 2026"
 #define GIT_DIRTY          "clean"
-#define GIT_TAG            "v0.53.2"
-#define GIT_COMMITS        "6790"
+#define GIT_TAG            "v0.53.3"
+#define GIT_COMMITS        "6793"
 
 #define AQUAMARINE_VERSION "0.10.0"
 // clang-format off
